@@ -26,6 +26,9 @@ from .window.__main__ import WindowDriverMethods
 class Browser:
     """Main class of Browserist that sets the Selenium web driver and contains all helper functions."""
 
+    __slots__ = ["_browser_driver", "driver", "ie", "safari",
+                 "check_if", "click", "combo", "get", "iframe", "input", "mouse", "open", "scroll", "select", "tool", "wait", "window"]
+
     def __init__(self, settings: BrowserSettings | None = None) -> None:
         """Initiates the browser driver whether the settings calls for Chrome, Firefox, etc."""
 
@@ -35,10 +38,13 @@ class Browser:
         self._browser_driver: BrowserDriver = factory.get.browser_driver(settings)
         self.driver: object = self._browser_driver.webdriver
 
-        if self._browser_driver.settings.type is BrowserType.INTERNET_EXPLORER:
-            self.ie: InternetExplorerBrowserExtension = InternetExplorerBrowserExtension(self._browser_driver)
-        if self._browser_driver.settings.type is BrowserType.SAFARI:
-            self.safari: SafariBrowserExtension = SafariBrowserExtension(self._browser_driver)
+        match self._browser_driver.settings.type:
+            case BrowserType.INTERNET_EXPLORER:
+                self.ie: InternetExplorerBrowserExtension = InternetExplorerBrowserExtension(self._browser_driver)
+            case BrowserType.SAFARI:
+                self.safari: SafariBrowserExtension = SafariBrowserExtension(self._browser_driver)
+            case _:
+                pass
 
         self.check_if: CheckIfDriverMethods = CheckIfDriverMethods(self._browser_driver, settings)
         self.click: ClickDriverMethods = ClickDriverMethods(self._browser_driver, settings)
