@@ -1,2 +1,2 @@
 def get_page_title(driver: object) -> str:
-    return driver.title
+    return driver.title  # type: ignore
