@@ -1,2 +1,2 @@
 def window_fullscreen(driver: object) -> None:
-    driver.fullscreen_window()
+    driver.fullscreen_window()  # type: ignore
