@@ -1,7 +1,10 @@
 from dataclasses import dataclass
 
+from ... import helper
+from ...model.type.xpath import XPath
 
-@dataclass
+
+@dataclass(kw_only=True, slots=True)
 class CookieBannerSettings:
     """Object with data needed to accept or decline cookies from a banner.
 
@@ -20,3 +23,8 @@ class CookieBannerSettings:
     has_loaded_wait_seconds: int | None = None
     has_loaded_xpath: str | None = None
     has_disappeared_wait_seconds: int | None = None
+
+    def __post_init__(self) -> None:
+        self.button_xpath = XPath(self.button_xpath)
+        self.url = helper.url.mediate_conversion_to_tiny_type_or_none(self.url)
+        self.has_loaded_xpath = helper.xpath.mediate_conversion_to_tiny_type_or_none(self.has_loaded_xpath)
